@@ -53,7 +53,7 @@ MESSAGE = """
 The Hypothesis command-line interface requires the `{}` package,
 which you do not have installed.  Run:
 
-    python -m pip install --upgrade hypothesis[cli]
+    python -m pip install --upgrade 'hypothesis[cli]'
 
 and try again.
 """
@@ -275,9 +275,7 @@ else:
         help="force ghostwritten tests to be type-annotated (or not).  "
         "By default, match the code to test.",
     )
-    def write(
-        func, writer, except_, style, annotate
-    ):  # noqa: D301  # \b disables autowrap
+    def write(func, writer, except_, style, annotate):  # \b disables autowrap
         """`hypothesis write` writes property-based tests for you!
 
         Type annotations are helpful but not required for our advanced introspection
