@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2021 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import attr
 
@@ -94,7 +89,7 @@ class GenericCache:
             if self.max_size == self.__pinned_entry_count:
                 raise ValueError(
                     "Cannot increase size of cache where all keys have been pinned."
-                )
+                ) from None
             entry = Entry(key, value, self.new_entry(key, value))
             if len(self.data) >= self.max_size:
                 evicted = self.data[0]
@@ -167,7 +162,7 @@ class GenericCache:
 
         Returns the score to associate with the key.
         """
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def on_access(self, key, value, score):
         """Called every time a key that is already in the map is read or
@@ -267,3 +262,16 @@ class LRUReusedCache(GenericCache):
         score[0] = 2
         score[1] = self.tick()
         return score
+
+    def pin(self, key):
+        try:
+            super().pin(key)
+        except KeyError:
+            # The whole point of an LRU cache is that it might drop things for you
+            assert key not in self.keys_to_indices
+
+    def unpin(self, key):
+        try:
+            super().unpin(key)
+        except KeyError:
+            assert key not in self.keys_to_indices
